@@ -1,5 +1,5 @@
 test_that("ClinicalTrials.gov minimum age downloads correctly", {
-    version <- clinicaltrials_gov_version("NCT02110043", 1, polite=FALSE)
+    version <- clinicaltrials_gov_version("NCT02110043", 1)
     if (version[1] == "Error") {
         expect_equal(
             version[1],
@@ -8,7 +8,7 @@ test_that("ClinicalTrials.gov minimum age downloads correctly", {
     } else {
         expect_equal(
             version$min_age,
-            "50"
+            "50 Years"
         )
     }
 })
